@@ -7,8 +7,6 @@ public:
   std::string solid_fill();
   std::string solid_fill_w14();
   std::string w_color();
-  std::string svg_fill_attr();
-  std::string svg_stroke_attr();
   int is_transparent();
 
 private:
