@@ -3,7 +3,7 @@ class main_tree
 public:
   main_tree (int, int, double, double, double, double, int );
   std::string a_opening_tag();
-  static std::string a_closing_tag();
+  static std::string a_closing_tag(int standalone);
   std::string x_opening_tag();
   static std::string x_closing_tag();
   std::string w_opening_tag();
